# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the wxPython project plugin.
"""

import sys
import os
import glob

from PyQt4.QtCore import QObject, SIGNAL, QTranslator, QString

from KdeQt.KQApplication import e4App

from Project.ProjectBrowser import SourcesBrowserFlag, FormsBrowserFlag, \
    ResourcesBrowserFlag, TranslationsBrowserFlag, InterfacesBrowserFlag, \
    OthersBrowserFlag, AllBrowsersFlag

import Preferences

# Start-of-Header
name = "wxPython Project Plugin"
author = "Detlev Offenbach <detlev@die-offenbachs.de>"
autoactivate = True
deactivateable = True
version = "1.0.3"
className = "ProjectWxPythonPlugin"
packageName = "ProjectWxPython"
shortDescription = "Project support for wxPython projects."
longDescription = """This plugin implements project support for wxPython projects."""
needsRestart = False
# End-of-Header

error = QString("")

def apiFiles(language):
    """
    Module function to return the API files made available by this plugin.
    
    @return list of API filenames (list of string)
    """
    if language == "Python":
        apisDir = \
            os.path.join(os.path.dirname(__file__), "ProjectWxPython", "APIs")
        apis = glob.glob(os.path.join(apisDir, '*.api'))
    else:
        apis = []
    return apis

def prepareUninstall():
    """
    Module function to prepare for an uninstallation.
    """
    wxPython = ProjectWxPythonPlugin(None)
    wxPython.prepareUninstall()
    
class ProjectWxPythonPlugin(QObject):
    """
    Class implementing the wxPython project plugin.
    """
    def __init__(self, ui):
        """
        Constructor
        
        @param ui reference to the user interface object (UI.UserInterface)
        """
        QObject.__init__(self, ui)
        self.__ui = ui
        self.__initialize()
        
        self.__translator = None
        self.__loadTranslator()
    
    def __initialize(self):
        """
        Private slot to (re)initialize the plugin.
        """
        self.__object = None
        
        self.__e4project = e4App().getObject("Project")
    
    def __checkVersions(self):
        """
        Private function to check that the eric4 version is ok.
        
        @return flag indicating version is ok (boolean)
        """
        global error
        
        if self.__ui.versionIsNewer('4.1.99', '20080229'):
            error = QString("")
        else:
            error = self.trUtf8("eric4 version is too old, %1, %2 or newer needed.")\
                .arg("4.2.0").arg("20080229")
            return False
        
        return True
    
    def activate(self):
        """
        Public method to activate this plugin.
        
        @return tuple of None and activation status (boolean)
        """
        if not self.__checkVersions():
            return None, False
        
        self.__e4project.registerProjectType("wxPython", self.trUtf8("wxPython"), 
            self.fileTypesCallback)
        Preferences.setProjectBrowserFlagsDefault("wxPython", 
            SourcesBrowserFlag | \
            InterfacesBrowserFlag | \
            OthersBrowserFlag, 
        )
        
        return None, True
    
    def deactivate(self):
        """
        Public method to deactivate this plugin.
        """
        self.__e4project.unregisterProjectType("wxPython")
        self.__initialize()
    
    def __loadTranslator(self):
        """
        Private method to load the translation file.
        """
        if self.__ui is not None:
            loc = self.__ui.getLocale()
            if loc and loc != "C":
                locale_dir = \
                    os.path.join(os.path.dirname(__file__), "ProjectWxPython", "i18n")
                translation = "wxpython_%s" % loc
                translator = QTranslator(None)
                loaded = translator.load(translation, locale_dir)
                if loaded:
                    self.__translator = translator
                    e4App().installTranslator(self.__translator)
                else:
                    print "Warning: translation file '%s' could not be loaded." % \
                        translation
                    print "Using default."
    
    def fileTypesCallback(self):
        """
        Public method get the filetype associations of the wxPython project type.
        
        @return dictionary with file type associations
        """
        fileTypes = {}
        return fileTypes
    
    def prepareUninstall(self):
        """
        Public method to prepare for an uninstallation.
        """
        Preferences.removeProjectBrowserFlags("wxPython")
