# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Django configuration page.
"""

import sys

from PyQt4.QtCore import QStringList

from Preferences.ConfigurationPages.ConfigurationPageBase import ConfigurationPageBase
from Ui_DjangoPage import Ui_DjangoPage

class DjangoPage(ConfigurationPageBase, Ui_DjangoPage):
    """
    Class implementing the Django configuration page.
    """
    def __init__(self, plugin):
        """
        Constructor
        
        @param plugin reference to the plugin object
        """
        ConfigurationPageBase.__init__(self)
        self.setupUi(self)
        self.setObjectName("DjangoPage")
        
        self.__plugin = plugin
        
        consoleList = QStringList()
        if sys.platform == "win32":
            consoleList.append("cmd.exe /c")
        else:
            consoleList.append("konsole -e")
            consoleList.append("konsole --workdir . -e")
            consoleList.append("gnome-terminal -x")
            consoleList.append("xterm -e")
        
        consoleNoCloseList = QStringList()
        if sys.platform == "win32":
            consoleNoCloseList.append("cmd.exe /k")
        else:
            consoleNoCloseList.append("konsole --noclose -e")
            consoleNoCloseList.append("konsole --noclose --workdir . -e")
            consoleNoCloseList.append("xterm -hold -e")
        
        self.consoleCommandCombo.addItems(consoleList)
        self.consoleCommandNoCloseCombo.addItems(consoleNoCloseList)
        
        # set initial values
        self.consoleCommandCombo.setEditText(
            self.__plugin.getPreferences("ConsoleCommand"))
        self.consoleCommandNoCloseCombo.setEditText(
            self.__plugin.getPreferences("ConsoleCommandNoClose"))
        
        self.serverAddressEdit.setText(
            self.__plugin.getPreferences("ServerAddress"))
        
        self.appsRecentSpinBox.setValue(
            self.__plugin.getPreferences("RecentNumberApps"))
        
        self.plainPythonCheckBox.setChecked(
            self.__plugin.getPreferences("UsePlainPython"))
    
    def save(self):
        """
        Public slot to save the Django configuration.
        """
        self.__plugin.setPreferences("ConsoleCommand", 
            self.consoleCommandCombo.currentText())
        self.__plugin.setPreferences("ConsoleCommandNoClose", 
            self.consoleCommandNoCloseCombo.currentText())
        
        self.__plugin.setPreferences("ServerAddress", 
            self.serverAddressEdit.text())
        
        self.__plugin.setPreferences("RecentNumberApps", 
            self.appsRecentSpinBox.value())
        
        self.__plugin.setPreferences("UsePlainPython", 
            int(self.plainPythonCheckBox.isChecked()))
