# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog to enter the data for the loaddata command.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from KdeQt import KQFileDialog

import Utilities

from Ui_DjangoLoaddataDataDialog import Ui_DjangoLoaddataDataDialog

class DjangoLoaddataDataDialog(QDialog, Ui_DjangoLoaddataDataDialog):
    """
    Class implementing a dialog to enter the data for the loaddata command.
    """
    def __init__(self, project, parent = None):
        """
        Constructor
        
        @param project reference to the Django project object
        @param parent parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        
        self.__project = project
        
        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
    
    @pyqtSignature("QString")
    def on_fixturesEdit_textChanged(self, txt):
        """
        Private slot to handle a change of the fixtures text.
        """
        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(not txt.isEmpty())
    
    @pyqtSignature("")
    def on_fixtureFileButton_clicked(self):
        """
        Private slot to select a fixture file via a file selection dialog.
        """
        fileFilters = self.trUtf8("JSON Files (*.json);;XML Files (*.xml);;")
        try:
            import yaml
            fileFilters.append(self.trUtf8("YAML Files (*.yaml);;"))
        except ImportError:
            pass
        fileFilters.append(self.trUtf8("All Files (*)"))
        
        selectedFilter = QString('')
        fixtureFile = KQFileDialog.getOpenFileName(\
            self,
            self.trUtf8("Select fixture file"),
            self.__project.getProjectPath(),
            fileFilters,
            selectedFilter)
        
        if not fixtureFile.isEmpty():
            ext = QFileInfo(fixtureFile).suffix()
            if ext.isEmpty():
                ex = selectedFilter.section('(*', 1, 1).section(')', 0, 0)
                if not ex.isEmpty():
                    fixtureFile.append(ex)
            self.fixturesEdit.setText(Utilities.toNativeSeparators(fixtureFile))
    
    def getData(self):
        """
        Public method to get the data entered into the dialog.
        
        @return list of fixtures (QStringList)
        """
        fixturesStr = self.fixturesEdit.text()
        fixtures = fixturesStr.split(" ", QString.SkipEmptyParts)
        
        return fixtures
