# -*- coding: utf-8 -*-

# Copyright (c) 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog to select the template type.
"""

from PyQt4.QtGui import QDialog, QDialogButtonBox
from PyQt4.QtCore import pyqtSignature, QVariant

from Ui_FormSelectionDialog import Ui_FormSelectionDialog

class FormSelectionDialog(QDialog, Ui_FormSelectionDialog):
    """
    Class implementing a dialog to select the template type.
    """
    def __init__(self, parent = None):
        """
        Constructor
        
        @param parent reference to the parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        
        self.templates = {
            "simple" : [self.trUtf8("Standard HTML template"), 
                '''<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"\n'''
                ''' "http://www.w3.org/TR/html4/strict.dtd">\n'''
                '''  <head>\n'''
                '''    <title></title>\n'''
                '''    <style>\n'''
                '''    </style>\n'''
                '''  </head>\n'''
                '''\n'''
                '''  <body>\n'''
                '''  </body>\n'''
                '''</html>\n'''
                ], 
            "sections" : [self.trUtf8("Mako template with sections"), 
                '''## -*- coding: utf-8 -*-\n'''
                '''\n'''
                '''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"\n'''
                ''' "http://www.w3.org/TR/html4/strict.dtd">\n'''
                '''<html>\n'''
                '''<head>\n'''
                '''    <title>${self.title()}</title>\n'''
                '''    ${self.head()}\n'''
                '''</head>\n'''
                '''<body>\n'''
                '''    ${self.header()}\n'''
                '''    ${self.tabs()}\n'''
                '''    ${self.menu()}\n'''
                '''    ${self.heading()}\n'''
                '''    ${self.breadcrumbs()}\n'''
                '''    ${next.body()}\n'''
                '''    ${self.footer()}\n'''
                '''</body>\n'''
                '''</html>\n'''
                '''\n'''
                '''<%def name="title()">SimpleSite</%def>\n'''
                '''<%def name="head()"></%def>\n'''
                '''<%def name="header()"><a name="top"></a></%def>\n'''
                '''<%def name="tabs()"></%def>\n'''
                '''<%def name="menu()"></%def>\n'''
                '''<%def name="heading()"><h1>${c.heading or 'No Title'}</h1></%def>\n'''
                '''<%def name="breadcrumbs()"></%def>\n'''
                '''<%def name="footer()"><p><a href="#top">Top ^</a></p></%def>\n'''
                ], 
        }
        
        self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
        self.__okButton.setEnabled(False)
        
        self.typeCombo.addItem("")
        for templateType in self.templates:
            self.typeCombo.addItem(self.templates[templateType][0], 
                                   QVariant(templateType))
        self.typeCombo.setCurrentIndex(0)
    
    @pyqtSignature("int")
    def on_typeCombo_currentIndexChanged(self, index):
        """
        Private slot to act upon a change of the selected template type.
        
        @param index selected index (integer)
        """
        data = self.typeCombo.itemData(index)
        if data.isValid():
            templateType = unicode(data.toString())
            self.preview.setPlainText(self.templates[templateType][1])
            self.__okButton.setEnabled(True)
        else:
            self.preview.clear()
            self.__okButton.setEnabled(False)

    def getTemplateText(self):
        """
        Public method to get the template text.
        
        @return text of the template (string)
        """
        templateType = unicode(
            self.typeCombo.itemData(self.typeCombo.currentIndex()).toString())
        return self.templates[templateType][1]
