# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the TurboGears project support.
"""

import os

from PyQt4.QtCore import *
from PyQt4.QtGui import *

from KdeQt.KQApplication import e4App
from KdeQt import KQFileDialog, KQMessageBox

class Project(QObject):
    """
    Class implementing the TurboGears project support.
    """
    def __init__(self, plugin, parent = None):
        """
        Constructor
        
        @param plugin reference to the plugin object
        @param parent parent (QObject)
        """
        QObject.__init__(self, parent)
        
        self.__plugin = plugin
        self.__ui = parent
        self.__e4project = e4App().getObject("Project")
        self.__hooksInstalled = False
        
        self.__mainMenu = None
    
    def initActions(self):
        """
        Public method to define the refactoring actions.
        """
        self.actions = []
    
    def initMenu(self):
        """
        Public slot to initialize the refactoring menu.
        
        @return the menu generated (QMenu)
        """
        menu = QMenu(self.trUtf8('Turbo&Gears'), self.__ui)
        menu.setTearOffEnabled(True)
        
        self.__mainMenu = menu
        return menu
    
    def projectOpenedHooks(self):
        """
        Public method to add our hook methods.
        """
        if self.__e4project.getProjectType() == "TurboGears":
            self.__formsBrowser = \
                e4App().getObject("ProjectBrowser").getProjectBrowser("forms")
            self.__formsBrowser.addHookMethod("newForm", self.newForm)
            self.__hooksInstalled = True
    
    def projectClosedHooks(self):
        """
        Public method to remove our hook methods.
        """
        if self.__hooksInstalled:
            self.__formsBrowser.removeHookMethod("newForm")
            self.__formsBrowser = None
            self.__hooksInstalled = False
    
    def newForm(self, path):
        """
        Public method to create a new form.
        
        @param path full directory path for the new form file (string)
        """
        selectedFilter = QString("")
        filter = self.trUtf8(
            "HTML Files (*.html);;KID Template Files (*.kid);;All Files (*)")
        fname = KQFileDialog.getSaveFileName(\
            self.__ui,
            self.trUtf8("New Form"),
            path,
            filter,
            selectedFilter,
            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
        
        if fname.isEmpty():
            # user aborted or didn't enter a filename
            return
        
        ext = QFileInfo(fname).suffix()
        if ext.isEmpty():
            ex = selectedFilter.section('(*',1,1).section(')',0,0)
            if not ex.isEmpty():
                fname.append(ex)
        
        fname = unicode(fname)
        if os.path.exists(fname):
            res = KQMessageBox.warning(self,
                self.trUtf8("New Form"),
                self.trUtf8("The file already exists! Overwrite it?"),
                QMessageBox.StandardButtons(\
                    QMessageBox.No | \
                    QMessageBox.Yes),
                QMessageBox.No)
            if res != QMessageBox.Yes:
                # user selected to not overwrite
                return
        
        try:
            f = open(fname, "wb")
            f.write('<!DOCTYPE html PUBLIC'
                    ' "-//W3C//DTD XHTML 1.0 Transitional//EN"'
                    ' "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\n')
            f.write('<html xmlns="http://www.w3.org/1999/xhtml"'
                    ' xmlns:py="http://purl.org/kid/ns#"'
                    ' py:extends="\'master.kid\'">\n')
            f.write('  <head>\n')
            f.write('    <meta content="text/html; charste=UTF-8"'
                    ' http-equiv="content-type"'
                    ' py:replace="\'\'" />\n')
            f.write('    <title></title>\n')
            f.write('    <style>\n')
            f.write('    </style>\n')
            f.write('  </head>\n')
            f.write('\n')
            f.write('  <body>\n')
            f.write('  </body>\n')
            f.write('</html>\n')
            f.close()
        except IOError, e:
            KQMessageBox.critical(self,
                self.trUtf8("New Form"),
                self.trUtf8("<p>The new form file <b>%1</b> could not be created.<br>"
                    "Problem: %2</p>").arg(fname).arg(unicode(e)))
            return
        
        self.__e4project.appendFile(fname)
        self.__formsBrowser.emit(SIGNAL('sourceFile'), fname)
