# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Confirmation dialog.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_ConfirmationDialog import Ui_ConfirmationDialog
from ChangesPreviewDialog import ChangesPreviewDialog

import Utilities

class ConfirmationDialog(QDialog, Ui_ConfirmationDialog):
    """
    Class implementing the Confirmation dialog.
    """
    def __init__(self, changes, parent = None):
        """
        Constructor
        
        @param changes reference to the Changes object (rope.base.change.ChangeSet)
        @param parent reference to the parent widget (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        
        self.__changes = changes
        
        self.description.setText(\
            self.trUtf8("Shall the refactoring <b>%1</b> be done?")\
                .arg(Utilities.html_encode(self.__changes.description)))
        
        self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
        self.__previewButton = self.buttonBox.addButton(\
            self.trUtf8("Preview"), QDialogButtonBox.ActionRole)
        self.__previewButton.setDefault(True)
    
    @pyqtSignature("QAbstractButton*")
    def on_buttonBox_clicked(self, button):
        """
        Private slot to act on the button pressed.
        
        @param button reference to the button pressed (QAbstractButton)
        """
        if button == self.__previewButton:
            self.__previewChanges()
    
    def __previewChanges(self):
        """
        Private method to preview the changes.
        """
        dlg = ChangesPreviewDialog(self.__changes, self)
        if dlg.exec_() == QDialog.Accepted:
            self.accept()
