# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a dialog to create getter and setter method names.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_GetterSetterDialog import Ui_GetterSetterDialog

class GetterSetterDialog(QDialog, Ui_GetterSetterDialog):
    """
    Class implementing a dialog to create getter and setter method names.
    """
    def __init__(self, fieldName, parent = None):
        """
        Constructor
        
        @param fieldName name of the field to create getter and setter 
            method names (string or QString)
        @param parent parent widget of the dialog (QWidget)
        """
        QDialog.__init__(self, parent)
        self.setupUi(self)
        
        self.__fieldName = fieldName
        
        self.on_typeCheckBox_toggled(False)
    
    @pyqtSignature("bool")
    def on_typeCheckBox_toggled(self, checked):
        """
        Slot to react to changes of the type checkbox.
        
        @param checked state of the checkbox (boolean)
        """
        if checked:
            self.getterEdit.setText("get_%s" % self.__fieldName)
            self.setterEdit.setText("set_%s" % self.__fieldName)
        else:
            self.getterEdit.setText(
                "get%s%s" % (self.__fieldName[0].upper(), self.__fieldName[1:]))
            self.setterEdit.setText(
                "set%s%s" % (self.__fieldName[0].upper(), self.__fieldName[1:]))
    
    def getData(self):
        """
        Public method to return the getter and setter method names.
        
        @return tuple of two unicode strings with getter and setter method names
        """
        return (unicode(self.getterEdit.text()), unicode(self.setterEdit.text()))
