# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Introduce Parameter dialog.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_IntroduceParameterDialog import Ui_IntroduceParameterDialog
from RefactoringDialogBase import RefactoringDialogBase

class IntroduceParameterDialog(RefactoringDialogBase, Ui_IntroduceParameterDialog):
    """
    Class implementing the Introduce Parameter dialog.
    """
    def __init__(self, refactoring, title, introducer, parent = None):
        """
        Constructor
         
        @param refactoring reference to the main refactoring object (Refactoring)
        @param title title of the dialog (string or QString)
        @param introducer reference to the factory introducer object 
            (rope.refactor.introduce_parameter.IntroduceParameter)
        @param parent reference to the parent widget (QWidget)
        """
        RefactoringDialogBase.__init__(self, refactoring, title, parent)
        self.setupUi(self)
        
        self.__introducer = introducer
        
        self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
        self.__okButton.setEnabled(False)
        self.__previewButton = self.buttonBox.addButton(\
            self.trUtf8("Preview"), QDialogButtonBox.ActionRole)
        self.__previewButton.setDefault(True)
        
        self.nameEdit.setText("new_parameter")
        self.nameEdit.selectAll()
    
    @pyqtSignature("QString")
    def on_nameEdit_textChanged(self, text):
        """
        Private slot to react to changes of the name.
        
        @param text text entered into the edit (QString)
        """
        self.__okButton.setEnabled(not text.isEmpty())
    
    @pyqtSignature("QAbstractButton*")
    def on_buttonBox_clicked(self, button):
        """
        Private slot to act on the button pressed.
        
        @param button reference to the button pressed (QAbstractButton)
        """
        if button == self.__previewButton:
            self.previewChanges()
        elif button == self.__okButton:
            self.applyChanges()
    
    def _calculateChanges(self, handle):
        """
        Protected method to calculate the changes.
        
        @param handle reference to the task handle (rope.base.taskhandle.TaskHandle)
        @return reference to the Changes object (rope.base.change.ChangeSet)
        """
        try:
            changes = self.__introducer.get_changes(unicode(self.nameEdit.text()))
            return changes
        except Exception, err:
            self._refactoring.handleRopeError(err, self._title, handle)
            return None
