# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Move Method dialog.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_MoveMethodDialog import Ui_MoveMethodDialog
from RefactoringDialogBase import RefactoringDialogBase

class MoveMethodDialog(RefactoringDialogBase, Ui_MoveMethodDialog):
    """
    Class implementing the Move Method dialog.
    """
    def __init__(self, refactoring, title, mover, parent = None):
        """
        Constructor
        
        @param refactoring reference to the main refactoring object (Refactoring)
        @param title title of the dialog (string or QString)
        @param mover reference to the mover object (rope.refactor.move.MoveMethod)
        @param parent reference to the parent widget (QWidget)
        """
        RefactoringDialogBase.__init__(self, refactoring, title, parent)
        self.setupUi(self)
        
        self.__mover = mover
        
        self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
        self.__okButton.setEnabled(False)
        self.__previewButton = self.buttonBox.addButton(\
            self.trUtf8("Preview"), QDialogButtonBox.ActionRole)
        self.__previewButton.setDefault(True)
        
        self.methodEdit.setText(self.__mover.get_method_name())
        self.methodEdit.selectAll()
    
    @pyqtSignature("QString")
    def on_attributeEdit_textChanged(self, txt):
        """
        Private slot to react to changes of the attribute.
        
        @param text text entered into the edit (QString)
        """
        self.__updateUI()
    
    @pyqtSignature("QString")
    def on_methodEdit_textChanged(self, txt):
        """
        Private slot to react to changes of the new method name.
        
        @param text text entered into the edit (QString)
        """
        self.__updateUI()
    
    @pyqtSignature("QAbstractButton*")
    def on_buttonBox_clicked(self, button):
        """
        Private slot to act on the button pressed.
        
        @param button reference to the button pressed (QAbstractButton)
        """
        if button == self.__previewButton:
            self.previewChanges()
        elif button == self.__okButton:
            self.applyChanges()
    
    def __updateUI(self):
        """
        Private method to perform various UI updates.
        """
        self.__okButton.setEnabled(\
            not self.attributeEdit.text().isEmpty() and \
            not self.methodEdit.text().isEmpty())
    
    def _calculateChanges(self, handle):
        """
        Protected method to calculate the changes.
        
        @param handle reference to the task handle (rope.base.taskhandle.TaskHandle)
        @return reference to the Changes object (rope.base.change.ChangeSet)
        """
        try:
            newName = unicode(self.methodEdit.text())
            if not newName:
                newName = None
            changes = self.__mover.get_changes(unicode(self.attributeEdit.text()), 
                newName, task_handle = handle)
            return changes
        except Exception, err:
            self._refactoring.handleRopeError(err, self._title, handle)
            return None
