# -*- coding: utf-8 -*-

# Copyright (c) 2008 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the Inline dialog.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *

from Ui_UseFunctionDialog import Ui_UseFunctionDialog
from RefactoringDialogBase import RefactoringDialogBase

class UseFunctionDialog(RefactoringDialogBase, Ui_UseFunctionDialog):
    """
    Class implementing the Inline dialog.
    """
    def __init__(self, refactoring, title, user, parent = None):
        """
        Constructor
        
        @param refactoring reference to the main refactoring object (Refactoring)
        @param title title of the dialog (string or QString)
        @param user reference to the usefunction object 
            (rope.refactor.usefunction.UseFunction)
        @param parent reference to the parent widget (QWidget)
        """
        RefactoringDialogBase.__init__(self, refactoring, title, parent)
        self.setupUi(self)
        
        self.__user = user
        
        self.description.setText(\
            self.trUtf8("Using Function <b>%1</b>.")\
                .arg(self.__user.get_function_name()))
        
        self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
        self.__previewButton = self.buttonBox.addButton(\
            self.trUtf8("Preview"), QDialogButtonBox.ActionRole)
        self.__previewButton.setDefault(True)
    
    @pyqtSignature("QAbstractButton*")
    def on_buttonBox_clicked(self, button):
        """
        Private slot to act on the button pressed.
        
        @param button reference to the button pressed (QAbstractButton)
        """
        if button == self.__previewButton:
            self.previewChanges()
        elif button == self.__okButton:
            self.applyChanges()
    
    def _calculateChanges(self, handle):
        """
        Protected method to calculate the changes.
        
        @param handle reference to the task handle (rope.base.taskhandle.TaskHandle)
        @return reference to the Changes object (rope.base.change.ChangeSet)
        """
        try:
            changes = self.__user.get_changes(task_handle = handle)
            return changes
        except Exception, err:
            self._refactoring.handleRopeError(err, self._title, handle)
            return None
